@@ -37,17 +37,19 @@ class Firebase:
     def setup(self) -> None:
         """Setup a firebase creating or reading an existing firebase configuration file"""
         self.agent_config.prompt()
-        log.debug(self.agent_config)
+        log.debug('New firebase setup: %s', self.agent_config)
 
     def upload(self, db_alias: str, file_paths: List[str], glob_exp: str) -> bool:
         """Upload files to firebase"""
         url = self.agent_config.url(db_alias)
         check_argument(len(file_paths) > 0, "Unable to upload file_paths (zero size).")
+        log.debug('Uploading files  alias=%s  files=%s', db_alias, ','.join(file_paths))
         return self.processor.upload_files(url, file_paths, glob_exp) > 0
 
     def download(self, db_alias: str, dest_dir: str) -> bool:
         """Download files from firebase specified by it's aliases"""
         url = self.agent_config.url(db_alias)
+        log.debug('Downloading files  alias=%s  dest_dir=%s', db_alias, dest_dir)
         return self.processor.download_files(url, dest_dir or os.environ.get('HOME')) > 0
 
     def is_configured(self) -> bool:
